@@ -16,8 +16,8 @@ class PV(DataSourceOutput):
         "power_mw",
         "capacity_mwp",
         "pv_system_row_number",
-        "x_coords",
-        "y_coords",
+        "x_osgb",
+        "y_osgb",
     )
 
     @classmethod
@@ -29,8 +29,8 @@ class PV(DataSourceOutput):
         v.check_data_var_dim(v.power_mw, ("example", "time_index", "id_index"))
         v.check_data_var_dim(v.capacity_mwp, ("example", "id_index"))
         v.check_data_var_dim(v.time, ("example", "time_index"))
-        v.check_data_var_dim(v.x_coords, ("example", "id_index"))
-        v.check_data_var_dim(v.y_coords, ("example", "id_index"))
+        v.check_data_var_dim(v.x_osgb, ("example", "id_index"))
+        v.check_data_var_dim(v.y_osgb, ("example", "id_index"))
         v.check_data_var_dim(v.pv_system_row_number, ("example", "id_index"))
 
         return v
